@@ -1,6 +1,6 @@
 #!/usr/pkg/bin/python3.12 -i
 #
-# Copyright 2013-2024 The Khronos Group Inc.
+# Copyright 2013-2025 The Khronos Group Inc.
 #
 # SPDX-License-Identifier: Apache-2.0
 
@@ -134,8 +134,10 @@ def mergeAPIs(tree, fromApiNames, toApiName):
                     definitionName = child.get('name')
                     definitionVariants = parent.findall(f"{child.tag}[@name='{definitionName}']")
                 elif child.tag in ['require']:
-                    definitionName = child.get('feature')
-                    definitionVariants = parent.findall(f"{child.tag}[@feature='{definitionName}']")
+                    # No way to correlate require tags because they do not have a definite identifier in the way they
+                    # are used in the latest forms of the XML so the best we can do is simply enable all of them
+                    if child.get('api') in fromApiNames:
+                        child.set('api', toApiName)
                 elif child.tag in ['command']:
                     definitionName = child.find('proto/name').text
                     definitionVariants = parent.findall(f"{child.tag}/proto/name[.='{definitionName}']/../..")
@@ -209,6 +211,10 @@ class BaseInfo:
         self.elem = elem
         "etree Element for this feature"
 
+        self.deprecatedbyversion = None
+        self.deprecatedbyextensions = []
+        self.deprecatedlink = None
+
     def resetState(self):
         """Reset required/declared to initial values. Used
         prior to generating a new API interface."""
@@ -347,6 +353,8 @@ class FeatureInfo(BaseInfo):
 
             self.number = 0
             self.supported = None
+
+            self.deprecates = elem.findall('deprecate')
         else:
             # Extract vendor portion of <APIprefix>_<vendor>_<name>
             self.category = self.name.split('_', 2)[1]
@@ -680,6 +688,9 @@ class Registry:
         # Now loop over aliases, injecting a copy of the aliased command's
         # Element with the aliased prototype name replaced with the command
         # name - if it exists.
+        # Copy the 'export' sttribute (whether it exists or not) from the
+        # original, aliased command, since that can be different for a
+        # command and its alias.
         for (name, alias, cmd) in cmdAlias:
             if alias in self.cmddict:
                 aliasInfo = self.cmddict[alias]
@@ -687,6 +698,14 @@ class Registry:
                 cmdElem.find('proto/name').text = name
                 cmdElem.set('name', name)
                 cmdElem.set('alias', alias)
+                export = cmd.get('export')
+                if export is not None:
+                    # Replicate the command's 'export' attribute
+                    cmdElem.set('export', export)
+                elif cmdElem.get('export') is not None:
+                    # Remove the 'export' attribute, if the alias has one but
+                    # the command does not.
+                    del cmdElem.attrib['export']
                 ci = CmdInfo(cmdElem)
                 # Replace the dictionary entry for the CmdInfo element
                 self.cmddict[name] = ci
@@ -799,7 +818,7 @@ class Registry:
                             if enum.get('alias'):
                                 format_name = enum.get('alias')
                             if format_name in format_condition:
-                                format_condition[format_name] += "," + featureInfo.name
+                                format_condition[format_name] += f",{featureInfo.name}"
                             else:
                                 format_condition[format_name] = featureInfo.name
                         elif groupName == "VkPipelineStageFlagBits2":
@@ -808,7 +827,7 @@ class Registry:
                                 stage_flag = enum.get('alias')
                             featureName = elem.get('depends') if elem.get('depends') is not None else featureInfo.name
                             if stage_flag in sync_pipeline_stage_condition:
-                                sync_pipeline_stage_condition[stage_flag] += "," + featureName
+                                sync_pipeline_stage_condition[stage_flag] += f",{featureName}"
                             else:
                                 sync_pipeline_stage_condition[stage_flag] = featureName
                         elif groupName == "VkAccessFlagBits2":
@@ -817,7 +836,7 @@ class Registry:
                                 access_flag = enum.get('alias')
                             featureName = elem.get('depends') if elem.get('depends') is not None else featureInfo.name
                             if access_flag in sync_access_condition:
-                                sync_access_condition[access_flag] += "," + featureName
+                                sync_access_condition[access_flag] += f",{featureName}"
                             else:
                                 sync_access_condition[access_flag] = featureName
 
@@ -989,7 +1008,7 @@ class Registry:
                     # Look up the Info with matching groupName
                     if groupName in self.groupdict:
                         gi = self.groupdict[groupName]
-                        gienum = gi.elem.find("enum[@name='" + enumname + "']")
+                        gienum = gi.elem.find(f"enum[@name='{enumname}']")
                         if gienum is not None:
                             # Remove copy of this enum from the group
                             gi.elem.remove(gienum)
@@ -1205,7 +1224,7 @@ class Registry:
                                 self.gen.featureDictionary[featurename][typecat][required_key][typeextends] = []
                             self.gen.featureDictionary[featurename][typecat][required_key][typeextends].append(typename)
                         else:
-                            self.gen.logMsg('warn', 'fillFeatureDictionary: NOT filling for {}'.format(typename))
+                            self.gen.logMsg('warn', f'fillFeatureDictionary: NOT filling for {typename}')
 
 
                 for enumElem in require.findall('enum'):
@@ -1222,7 +1241,7 @@ class Registry:
                             self.gen.featureDictionary[featurename]['enumconstant'][required_key][enumextends] = []
                         self.gen.featureDictionary[featurename]['enumconstant'][required_key][enumextends].append(enumname)
                     else:
-                        self.gen.logMsg('warn', 'fillFeatureDictionary: NOT filling for {}'.format(typename))
+                        self.gen.logMsg('warn', f'fillFeatureDictionary: NOT filling for {typename}')
 
                 for cmdElem in require.findall('command'):
                     # Remove aliases in the same extension/feature; these are always added as a correction. Do not need the original to be visible.
@@ -1232,7 +1251,7 @@ class Registry:
                             self.gen.featureDictionary[featurename]['command'][required_key] = []
                         self.gen.featureDictionary[featurename]['command'][required_key].append(cmdElem.get('name'))
                     else:
-                        self.gen.logMsg('warn', 'fillFeatureDictionary: NOT filling for {}'.format(typename))
+                        self.gen.logMsg('warn', f'fillFeatureDictionary: NOT filling for {typename}')
 
     def requireFeatures(self, interface, featurename, api, profile):
         """Process `<require>` tags for a `<version>` or `<extension>`.
@@ -1248,6 +1267,51 @@ class Registry:
             if matchAPIProfile(api, profile, feature):
                 self.markRequired(featurename, feature, True)
 
+    def deprecateFeatures(self, interface, featurename, api, profile):
+        """Process `<require>` tags for a `<version>` or `<extension>`.
+
+        - interface - Element for `<version>` or `<extension>`, containing
+          `<require>` tags
+        - featurename - name of the feature
+        - api - string specifying API name being generated
+        - profile - string specifying API profile being generated"""
+
+        versionmatch = APIConventions().is_api_version_name(featurename)
+
+        # <deprecate> marks things that are deprecated by this version/profile
+        for deprecation in interface.findall('deprecate'):
+            if matchAPIProfile(api, profile, deprecation):
+                for typeElem in deprecation.findall('type'):
+                    type = self.lookupElementInfo(typeElem.get('name'), self.typedict)
+                    if type:
+                        if versionmatch is not False:
+                            type.deprecatedbyversion = featurename
+                        else:
+                            type.deprecatedbyextensions.append(featurename)
+                        type.deprecatedlink = deprecation.get('explanationlink')
+                    else:
+                        self.gen.logMsg('error', typeElem.get('name'), ' is tagged for deprecation but not present in registry')
+                for enumElem in deprecation.findall('enum'):
+                    enum = self.lookupElementInfo(enumElem.get('name'), self.enumdict)
+                    if enum:
+                        if versionmatch is not False:
+                            enum.deprecatedbyversion = featurename
+                        else:
+                            enum.deprecatedbyextensions.append(featurename)
+                        enum.deprecatedlink = deprecation.get('explanationlink')
+                    else:
+                        self.gen.logMsg('error', enumElem.get('name'), ' is tagged for deprecation but not present in registry')
+                for cmdElem in deprecation.findall('command'):
+                    cmd = self.lookupElementInfo(cmdElem.get('name'), self.cmddict)
+                    if cmd:
+                        if versionmatch is not False:
+                            cmd.deprecatedbyversion = featurename
+                        else:
+                            cmd.deprecatedbyextensions.append(featurename)
+                        cmd.deprecatedlink = deprecation.get('explanationlink')
+                    else:
+                        self.gen.logMsg('error', cmdElem.get('name'), ' is tagged for deprecation but not present in registry')
+
     def removeFeatures(self, interface, featurename, api, profile):
         """Process `<remove>` tags for a `<version>` or `<extension>`.
 
@@ -1748,6 +1812,7 @@ class Registry:
             self.gen.logMsg('diag', 'PASS 1: Tagging required and features for', f.name)
             self.fillFeatureDictionary(f.elem, f.name, self.genOpts.apiname, self.genOpts.profile)
             self.requireFeatures(f.elem, f.name, self.genOpts.apiname, self.genOpts.profile)
+            self.deprecateFeatures(f.elem, f.name, self.genOpts.apiname, self.genOpts.profile)
             self.assignAdditionalValidity(f.elem, self.genOpts.apiname, self.genOpts.profile)
 
         for f in features:
